@@ -1,4 +1,5 @@
-package DBICTest::Extra;
+package # hide from PAUSE 
+    DBICTest::Extra;
 use base 'DBIx::Class::Schema';
 
 __PACKAGE__->load_classes("Foo");
