@@ -1,6 +1,6 @@
 -- 
 -- Created by SQL::Translator::Producer::SQLite
--- Created on Sat May 27 21:28:05 2006
+-- Created on Thu Jun 22 22:47:36 2006
 -- 
 BEGIN TRANSACTION;
 
@@ -22,14 +22,6 @@ CREATE TABLE serialized (
   serialized text NOT NULL
 );
 
---
--- Table: liner_notes
---
-CREATE TABLE liner_notes (
-  liner_id INTEGER PRIMARY KEY NOT NULL,
-  notes varchar(100) NOT NULL
-);
-
 --
 -- Table: cd_to_producer
 --
@@ -39,6 +31,14 @@ CREATE TABLE cd_to_producer (
   PRIMARY KEY (cd, producer)
 );
 
+--
+-- Table: liner_notes
+--
+CREATE TABLE liner_notes (
+  liner_id INTEGER PRIMARY KEY NOT NULL,
+  notes varchar(100) NOT NULL
+);
+
 --
 -- Table: artist
 --
@@ -47,6 +47,20 @@ CREATE TABLE artist (
   name varchar(100)
 );
 
+--
+-- Table: fourkeys_to_twokeys
+--
+CREATE TABLE fourkeys_to_twokeys (
+  f_foo integer NOT NULL,
+  f_bar integer NOT NULL,
+  f_hello integer NOT NULL,
+  f_goodbye integer NOT NULL,
+  t_artist integer NOT NULL,
+  t_cd integer NOT NULL,
+  autopilot character NOT NULL,
+  PRIMARY KEY (f_foo, f_bar, f_hello, f_goodbye, t_artist, t_cd)
+);
+
 --
 -- Table: twokeytreelike
 --
@@ -96,23 +110,6 @@ CREATE TABLE track (
   title varchar(100) NOT NULL
 );
 
---
--- Table: self_ref
---
-CREATE TABLE self_ref (
-  id INTEGER PRIMARY KEY NOT NULL,
-  name varchar(100) NOT NULL
-);
-
---
--- Table: tags
---
-CREATE TABLE tags (
-  tagid INTEGER PRIMARY KEY NOT NULL,
-  cd integer NOT NULL,
-  tag varchar(100) NOT NULL
-);
-
 --
 -- Table: treelike
 --
@@ -122,6 +119,14 @@ CREATE TABLE treelike (
   name varchar(100) NOT NULL
 );
 
+--
+-- Table: self_ref
+--
+CREATE TABLE self_ref (
+  id INTEGER PRIMARY KEY NOT NULL,
+  name varchar(100) NOT NULL
+);
+
 --
 -- Table: link
 --
@@ -131,12 +136,22 @@ CREATE TABLE link (
   title varchar(100)
 );
 
+--
+-- Table: tags
+--
+CREATE TABLE tags (
+  tagid INTEGER PRIMARY KEY NOT NULL,
+  cd integer NOT NULL,
+  tag varchar(100) NOT NULL
+);
+
 --
 -- Table: event
 --
 CREATE TABLE event (
   id INTEGER PRIMARY KEY NOT NULL,
-  starts_at datetime NOT NULL
+  starts_at datetime NOT NULL,
+  created_on timestamp NOT NULL
 );
 
 --
@@ -156,6 +171,7 @@ CREATE TABLE fourkeys (
   bar integer NOT NULL,
   hello integer NOT NULL,
   goodbye integer NOT NULL,
+  sensors character NOT NULL,
   PRIMARY KEY (foo, bar, hello, goodbye)
 );
 
@@ -168,6 +184,14 @@ CREATE TABLE artist_undirected_map (
   PRIMARY KEY (id1, id2)
 );
 
+--
+-- Table: producer
+--
+CREATE TABLE producer (
+  producerid INTEGER PRIMARY KEY NOT NULL,
+  name varchar(100) NOT NULL
+);
+
 --
 -- Table: onekey
 --
@@ -177,14 +201,6 @@ CREATE TABLE onekey (
   cd integer NOT NULL
 );
 
---
--- Table: producer
---
-CREATE TABLE producer (
-  producerid INTEGER PRIMARY KEY NOT NULL,
-  name varchar(100) NOT NULL
-);
-
 CREATE UNIQUE INDEX tktlnameunique_twokeytreelike on twokeytreelike (name);
 CREATE UNIQUE INDEX cd_artist_title_cd on cd (artist, title);
 CREATE UNIQUE INDEX prod_name_producer on producer (name);
